Triangle
---------

|Triangle Build Status| |Triangle Version Status| |Triangle Downloads|

.. |Triangle Build Status| image:: https://travis-ci.org/drufat/triangle.png
   :target: https://travis-ci.org/drufat/triangle
.. |Triangle Version Status| image:: https://img.shields.io/pypi/v/triangle.svg
   :target: https://pypi.python.org/pypi/triangle/
.. |Triangle Downloads| image:: https://img.shields.io/pypi/dm/triangle.svg
   :target: https://pypi.python.org/pypi/triangle/

*Triangle* is a python wrapper around Jonathan Richard Shewchuk's two-dimensional quality mesh generator and delaunay triangulator library, available `here <quake_>`_. This implementation utilizes Cython_ to wrap the C API as closely as possible. The source is available on Github_, and the documentation can be accessed at `rufat.be/triangle <https://rufat.be/triangle>`_.

.. _quake: http://www.cs.cmu.edu/~quake/triangle.html
.. _Cython: https://cython.org
.. _Github: https://github.com/drufat/triangle

